==> runtime-tools-quarkus-extension-deployment-1.41.0.Final.jar: dev-static/webapp/components/pages/FormDetailsPage/components/FormDetailsNotification/FormDetailsNotification.js <==
"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
Object.defineProperty(exports, "__esModule", { value: true });
var jsx_runtime_1 = require("react/jsx-runtime");
var react_1 = __importStar(require("react"));
var react_core_1 = require("@patternfly/react-core");
var ouia_tools_1 = require("@kogito-apps/ouia-tools");
var FormDetailsNotification = function (_a) {
    var notification = _a.notification, ouiaId = _a.ouiaId, ouiaSafe = _a.ouiaSafe;
    var variant = notification.type === 'error' ? 'danger' : 'success';
    var _b = __read((0, react_1.useState)(false), 2), showDetails = _b[0], setShowDetails = _b[1];
    return ((0, jsx_runtime_1.jsx)(react_core_1.Alert, __assign({ isInline: true, title: notification.message, variant: variant, actionLinks: (0, jsx_runtime_1.jsx)(react_1.default.Fragment, { children: notification.details && ((0, jsx_runtime_1.jsx)(react_core_1.AlertActionLink, __assign({ onClick: function () { return setShowDetails(!showDetails); } }, { children: "View details" }))) }), actionClose: (0, jsx_runtime_1.jsx)(react_core_1.AlertActionCloseButton, { onClose: notification.close }) }, (0, ouia_tools_1.componentOuiaProps)(ouiaId, 'notification-alert', ouiaSafe), { children: showDetails && notification.details && (0, jsx_runtime_1.jsx)("p", { children: notification.details }) })));
};
exports.default = FormDetailsNotification;
//# sourceMappingURL=FormDetailsNotification.js.map

==> runtime-tools-quarkus-extension-deployment-1.44.1.Final.jar: dev-static/webapp/components/pages/FormDetailsPage/components/FormDetailsNotification/FormDetailsNotification.js <==
"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
Object.defineProperty(exports, "__esModule", { value: true });
var jsx_runtime_1 = require("react/jsx-runtime");
var react_1 = __importStar(require("react"));
var Alert_1 = require("@patternfly/react-core/dist/js/components/Alert");
var OuiaUtils_1 = require("@kogito-apps/ouia-tools/dist/utils/OuiaUtils");
var FormDetailsNotification = function (_a) {
    var notification = _a.notification, ouiaId = _a.ouiaId, ouiaSafe = _a.ouiaSafe;
    var variant = notification.type === 'error' ? 'danger' : 'success';
    var _b = __read((0, react_1.useState)(false), 2), showDetails = _b[0], setShowDetails = _b[1];
    return ((0, jsx_runtime_1.jsx)(Alert_1.Alert, __assign({ isInline: true, title: notification.message, variant: variant, actionLinks: (0, jsx_runtime_1.jsx)(react_1.default.Fragment, { children: notification.details && ((0, jsx_runtime_1.jsx)(Alert_1.AlertActionLink, __assign({ onClick: function () { return setShowDetails(!showDetails); } }, { children: "View details" }))) }), actionClose: (0, jsx_runtime_1.jsx)(Alert_1.AlertActionCloseButton, { onClose: notification.close }) }, (0, OuiaUtils_1.componentOuiaProps)(ouiaId, 'notification-alert', ouiaSafe), { children: showDetails && notification.details && (0, jsx_runtime_1.jsx)("p", { children: notification.details }) })));
};
exports.default = FormDetailsNotification;
//# sourceMappingURL=FormDetailsNotification.js.map
